Module blaxel.core.client.models.integration_organization
=========================================================

Classes
-------

`IntegrationOrganization(avatar_url: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, display_name: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, id: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, name: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>)`
:   Integration organization
    
    Attributes:
        avatar_url (Union[Unset, str]): Provider organization avatar URL
        display_name (Union[Unset, str]): Provider organization display name
        id (Union[Unset, str]): Provider organization ID
        name (Union[Unset, str]): Provider organization name
    
    Method generated by attrs for class IntegrationOrganization.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `avatar_url: blaxel.core.client.types.Unset | str`
    :

    `display_name: blaxel.core.client.types.Unset | str`
    :

    `id: blaxel.core.client.types.Unset | str`
    :

    `name: blaxel.core.client.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :